@@ -1,6 +1,6 @@
 ;;; hui-mouse.el --- Use key or mouse key for many functions, e.g. Hypb menus.
 
-;; Copyright (C) 1989-1995, 2006 Free Software Foundation, Inc.
+;; Copyright (C) 1989-1995, 2006, 2008 Free Software Foundation, Inc.
 ;; Developed with support from Motorola Inc.
 
 ;; Author: Bob Weiner, Brown U.
@@ -211,6 +211,9 @@
     ((eq major-mode 'Buffer-menu-mode) .
      ((smart-buffer-menu) . (smart-buffer-menu-assist)))
     ;;
+    ((eq major-mode 'ibuffer-mode) .
+     ((smart-ibuffer-menu) . (smart-ibuffer-menu-assist)))
+    ;;
     ((eq major-mode 'dired-mode) . 
      ((smart-dired) . (smart-dired-assist)))
     ;;
@@ -362,6 +365,61 @@ If assist-key is pressed:
 	 (Buffer-menu-unmark))
 	(t (Buffer-menu-delete))))
 
+;;;
+;;; smart-ibuffer-menu functions
+;;;
+
+(defun smart-ibuffer-menu (&optional in-browser)
+  "Uses a single key or mouse key to manipulate ibuffer entries.
+
+Invoked via a key press when in ibuffer-mode.  It assumes that its
+caller has already checked that the key was pressed in an appropriate buffer
+and has moved the cursor there.
+
+Optional non-nil IN-BROWSER indicates use within the OO-Browser.
+
+If key is pressed:
+ (1) on the first or second column of an entry, the selected buffer is
+     marked for display;
+ (3) anywhere else within an entry line, all selected buffers are
+     displayed, including the one just clicked on (if IN-BROWSER, only
+     the selected buffer is displayed);
+ (4) on or after the last line in the buffer, all deletes are done."
+
+  (interactive)
+  (cond ((last-line-p) (progn (ibuffer-do-kill-on-deletion-marks)))
+	((bolp) (ibuffer-mark-forward 1))
+        ((save-excursion
+             (goto-char (1- (point)))
+	     (bolp))
+	 (ibuffer-mark-forward 1))
+	(in-browser (br-buffer-menu-select))  
+	(t (ibuffer-do-view))))
+
+(defun smart-ibuffer-menu-assist ()
+  "Uses a single assist-key or mouse assist-key to manipulate buffer-menu entries.
+
+Invoked via an assist-key press when in ibuffer-mode.  It assumes that
+its caller has already checked that the assist-key was pressed in an
+appropriate buffer and has moved the cursor there.
+
+If assist-key is pressed:
+ (1) on the first or second column of an entry, the selected buffer is unmarked
+     for display or deletion; 
+ (2) anywhere else within an entry line, the selected buffer is marked for
+     deletion;
+ (3) on or after the last line in the buffer, all display, save, and delete
+     marks on all entries are undone."
+
+  (interactive)
+  (cond ((last-line-p) (ibuffer-unmark-all 0))
+	((bolp) (ibuffer-unmark-forward 1))
+        ((save-excursion
+             (goto-char (1- (point)))
+	     (bolp))
+	 (ibuffer-unmark-forward 1))
+	(t (ibuffer-mark-for-delete 1))))
+
 ;;;
 ;;; smart-calendar functions
 ;;;
