@@ -1,6 +1,6 @@
 ;;; hui.el --- GNU Emacs User Interface to Hyperbole
 
-;; Copyright (C) 1991-1995, Free Software Foundation, Inc.
+;; Copyright (C) 1991-1995, 2008 Free Software Foundation, Inc.
 ;; Developed with support from Motorola Inc.
 
 ;; Author: Bob Weiner, Brown U.
@@ -364,10 +364,8 @@ BUT defaults to the button whose label point is within."
       (cond (but (hypb:error "(hbut-help): Invalid button."))
 	    (t   (hypb:error
 		  "(hbut-help): Not on an implicit button and no buffer explicit buttons."))))
-  (let ((type-help-func (intern-soft
-			 (concat 
-			  (htype:names 'ibtypes (hattr:get but 'categ))
-			  ":help"))))
+  (let* ((sym-name (htype:names 'ibtypes (hattr:get but 'categ)))
+	 (type-help-func (if sym-name (intern-soft (concat sym-name ":help")))))
     (or (equal (hypb:indirect-function 'hui:but-flash)
 	       (function (lambda nil)))
 	;; Only flash button if point is on it.
